Learn R Programming

CamelUp (version 0.1.1)

bet: A bet object that is placed for a leg on a given camel

Description

A bet object that is placed for a leg on a given camel

Usage

bet

Arguments

Format

An object of class R6ClassGenerator of length 24.

Examples

Run this code
# NOT RUN {
x <- bet$new("blue", 5)
# }

Run the code above in your browser using DataLab