Learn R Programming

CamelUp (version 0.1.0)

board: A board object on which the game is played

Description

A board object on which the game is played

Usage

board

Arguments

Format

An object of class R6ClassGenerator of length 24.

Examples

Run this code
# NOT RUN {
y <- system$new(nPlayers = 2, players = c("Michael", "Alex"))
x <- board$new(y)
# }

Run the code above in your browser using DataLab