Learn R Programming

CamelUp (version 0.1.0)

camel: Implements camel class based off of the board game pieces

Description

Implements camel class based off of the board game pieces

Usage

camel

Arguments

Format

An object of class R6ClassGenerator of length 24.

Examples

Run this code
# NOT RUN {
x <- camel$new("blue", 1, 1)
# }

Run the code above in your browser using DataLab