Learn R Programming

CamelUp (version 0.1.0)

die: A three sided die, assigned a color corresponding to a camel

Description

A three sided die, assigned a color corresponding to a camel

Usage

die

Arguments

Format

An object of class R6ClassGenerator of length 24.

Examples

Run this code
# NOT RUN {
x <- die$new("blue")
# }

Run the code above in your browser using DataLab