Learn R Programming

CamelUp (version 0.1.0)

overall.bet: A bet object that is placed overall on a given camel

Description

A bet object that is placed overall on a given camel

Usage

overall.bet

Arguments

Format

An object of class R6ClassGenerator of length 24.

Examples

Run this code
# NOT RUN {
s <- system$new(nPlayers = 2, players = c("Michael", "Alex"))
p <- s$players[[1]]
x <- overall.bet$new("blue", p)
# }

Run the code above in your browser using DataLab