Learn R Programming

CamelUp (version 0.1.0)

stack: Implements a classic stack with push, pop and a few other methods

Description

Implements a classic stack with push, pop and a few other methods

Usage

stack

Arguments

Format

An object of class R6ClassGenerator of length 24.

Examples

Run this code
# NOT RUN {
x <- stack$new()
x$push(5)
y <- x$pop()
# }

Run the code above in your browser using DataLab